<?php
/**
 * @file
 * Contains all functionality handling stylesheets.
 */

/**
 * Implements hook_css_alter().
 *
 * Remove Drupal's core system stylesheets.
 * They aren't compatible with the Rijkshuisstijl & starterskit library.
 */
function rijkshuisstijl_css_alter(&$css) {
  $exclude = array(
    'modules/system/system.base.css' => FALSE,
    'modules/system/system.menus.css' => FALSE,
    'modules/system/system.messages.css' => FALSE,
    'modules/system/system.theme.css' => FALSE,
  );

  if (module_exists('webform')) {
    $exclude[drupal_get_path('module', 'webform') . '/css/webform.css'] = FALSE;
  }

  if (module_exists('addressfield')) {
    $exclude[drupal_get_path('module', 'addressfield') . '/addressfield.css'] = FALSE;
  }

  if (module_exists('site_map')) {
    $exclude[drupal_get_path('module', 'site_map') . '/site_map.theme.css'] = FALSE;
  }

  $css = array_diff_key($css, $exclude);

  // Use Rijkshuisstijl vertical tabs style instead of the default one.
  if (isset($css['misc/vertical-tabs.css'])) {
    $css['misc/vertical-tabs.css']['data'] = drupal_get_path('theme', 'rijkshuisstijl') . '/styles/vertical-tabs.css';
    $css['misc/vertical-tabs.css']['type'] = 'file';
  }

  // Use Rijkshuisstijl jQuery UI theme style instead of the default one.
  // if (isset($css['misc/ui/jquery.ui.theme.css'])) {
  //   $css['misc/ui/jquery.ui.theme.css']['data'] = drupal_get_path('theme', 'rijkshuisstijl') . '/styles/jquery.ui.theme.css';
  //   $css['misc/ui/jquery.ui.theme.css']['type'] = 'file';
  // }
  //
}

/**
 * This functions includes all the starterkit library stylesheets.
 */
function rijkshuisstijl_add_stylesheets(&$variables) {
  $theme_path = drupal_get_path('theme', 'rijkshuisstijl');

  // Add conditional stylesheets for IE.
  drupal_add_css($theme_path . '/styles/ie/ie.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => TRUE,
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
    )
  );

  drupal_add_css($theme_path . '/styles/ie/ie-7.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => 'IE 7',
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
    )
  );

  drupal_add_css($theme_path . '/styles/ie/ie-8.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => 'IE 8',
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
    )
  );

  //
  // set stylesheet for starterskit
  //

  if (!isset($variables['starterskit']['library path'])){
    $starterskitlibrarypath = variable_get('maintenance_content');
  }
    else{
    $starterskitlibrarypath = $variables['starterskit']['library path'];
  }

  // Add the favicon from the starterskit as default.
  if (theme_get_setting('default_favicon')) {
    drupal_add_html_head_link(array(
      'rel' => 'shortcut icon',
      'href' => url($starterskitlibrarypath . '/favicon.ico', array(
        'absolute' => TRUE,
      )),
      'type' => 'image/vnd.microsoft.icon'
    ));
  }

  drupal_add_css($starterskitlibrarypath. '/css/screen.css',
    array(
      'group' => CSS_THEME,
      'every_page' => TRUE,
      'preprocess' => TRUE,
      'media' => 'screen',
      'weight' => -100,
    )
  );
  drupal_add_css($starterskitlibrarypath . '/css/ie/ie6.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => TRUE,
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
      'weight' => -100,
    )
  );

  drupal_add_css($starterskitlibrarypath . '/css/ie/ie7.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => 'IE 7',
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
      'weight' => -100,
    )
  );

  drupal_add_css($starterskitlibrarypath . '/css/ie/ie8.css',
    array(
      'group' => CSS_THEME,
      'browsers' => array(
        'IE' => 'IE 8',
        '!IE' => FALSE,
      ),
      'preprocess' => FALSE,
      'every_page' => TRUE,
      'media' => 'screen',
      'weight' => -100,
    )
  );
  drupal_add_css($starterskitlibrarypath . '/css/print.css',
    array(
      'group' => CSS_THEME,
      'every_page' => TRUE,
      'preprocess' => TRUE,
      'media' => 'print',
    )
  );

}
